==> trade_utils-1.0.23-py3-none-any.whl: algo/data/reader.py <==
import logging
from datetime import datetime, timedelta

from influxdb_client.client.flux_table import TableList


from algo.data.connection import DataConnection
from algo.data.common import PricePoint, PriceStream
from algo.data.cache import cached, day_data_cache_key, week_data_cache_key
from algo.util import d, dt_to_rfc3339
from algo.constant import Symbol
from algo.config import config


log = logging.getLogger(__name__)


class DataReader(DataConnection):
    def __init__(self, url, token=None, org=None):
        super().__init__(url, token, org)
        self._query_api = self._client.query_api()

    def hour_data(self, date_str: str, symbol: Symbol) -> PriceStream:
        start = datetime.fromisoformat(date_str)
        end = start + timedelta(hours=1)
        yield from cached(
            f'hour-data-{symbol.value}-{start.isoformat()}',
            self.get_data_stream(start, end, symbol)
        )

    def day_data(self, date_str: str, symbol: Symbol) -> PriceStream:
        start = datetime.fromisoformat(date_str)
        end = start + timedelta(days=1)
        yield from cached(
            day_data_cache_key(symbol.value, start.isoformat()),
            self.get_data_stream(start, end, symbol)
        )

    def day_data_no_cache(self, date_str: str, symbol: Symbol) -> PriceStream:
        start = datetime.fromisoformat(date_str)
        end = start + timedelta(days=1)
        yield from self.get_data_stream(start, end, symbol)

    def week_data_direct(self, date_str: str, symbol: Symbol) -> PriceStream:
        # TBD: use algo.util.get_week_start_day
        week_dt = datetime.fromisoformat(date_str)
        start = week_dt - timedelta(days=week_dt.weekday())
        end = start + timedelta(days=6)
        yield from cached(
            # here to replace with cache-key
            week_data_cache_key(symbol.value, start.isoformat()),
            self.get_data_stream(start, end, symbol)
        )

    def week_data(self, date_str: str, symbol: Symbol) -> PriceStream:
        week_dt = datetime.fromisoformat(date_str)
        start = week_dt - timedelta(days=week_dt.weekday())
        end = start + timedelta(days=6)
        # 1 weeek data set is too big to cache at this point so doing it iteratively
        current_day = start
        while current_day <= end:
            log.info(
                'getting data for the week by the day',
                extra=d(current_day)
            )
            yield from self.day_data(current_day.isoformat(), symbol)
            current_day += timedelta(days=1)

    def get_result_set(self, symbol: Symbol, start: datetime, end: datetime) -> TableList:
        query_str = f"""
            from(bucket: "tsdata")
              |> range(start: {dt_to_rfc3339(start)}, stop: {dt_to_rfc3339(end)})
              |> filter(fn: (r) => r["instrument"] == "{symbol.value}")
              |> filter(fn: (r) => r["_measurement"] == "price")
              |> pivot(rowKey: ["_time"], columnKey: ["_field"], valueColumn: "_value")
        """
        return self._query_api.query(query_str)

    def get_data_stream(
            self, start: datetime, end: datetime, symbol: Symbol
    ) -> PriceStream:
        log.debug('getting chunk starting', extra=d(start))
        results = self.get_result_set(symbol, start, end)
        log.info('query-result', extra={'r': results})

        for _time, ask, bid in results.to_values(columns=('_time', 'ask', 'bid')):
            yield PricePoint(_time, ask, bid)

    def get_data_stream_iterative_ready(
            self, start: datetime, end: datetime, symbol: Symbol
    ) -> PriceStream:
        """
        not in use consider removal
        """
        current_start = start
        keep_loading = True
        while keep_loading and current_start < end:
            log.debug('getting next chunk %s', current_start)
            results = self.get_result_set(symbol, current_start, end)
            log.info('query-result', extra={'r': results})
            for flux_table in results:
                for record in flux_table:
                    # following extra condition is present due to milliseconds round up of the influx
                    keep_loading = current_start <= record['_time']
                    if keep_loading:
                        current_start = record['_time']
                        log.info('current_start', extra=d(start=current_start))
                        if PricePoint.is_valid_price_dict(record):
                            yield PricePoint(record['_time'], record['ask'], record['bid'])


def get_data_reader() -> DataReader:
    return DataReader(
        config.influx_url,
        config.influx_token,
        config.influx_org
    )

==> trade_utils-1.0.24-py3-none-any.whl: algo/data/reader.py <==
import logging
from datetime import datetime, timedelta, date
from dateutil import tz

from influxdb_client.client.flux_table import TableList


from algo.data.connection import DataConnection
from algo.data.common import PricePoint, PriceStream
from algo.util import d, dt_to_rfc3339, get_week_start_day, is_dt_naive
from algo.constant import Symbol
from algo.config import config


log = logging.getLogger(__name__)


class DataReader(DataConnection):
    def __init__(self, url, token=None, org=None):
        super().__init__(url, token, org)
        self._query_api = self._client.query_api()

    # TBD: consider removing
    def hour_data(self, hour_start: datetime, symbol: Symbol) -> PriceStream:
        """
        treats timezone naive data in hour_data as UTC
        """
        start = hour_start.replace(tzinfo=tz.tzutc()) if is_dt_naive(hour_start) else hour_start
        end = start + timedelta(hours=1)
        yield from self.get_data_stream(start, end, symbol)

    def day_data(self, day: date, symbol: Symbol) -> PriceStream:
        start = datetime.combine(
            day, datetime.min.time(), tz.tzutc()
        )
        end = start + timedelta(days=1)
        yield from self.get_data_stream(start, end, symbol)

    def week_data(self, week_day: date, symbol: Symbol) -> PriceStream:
        week_start_date = get_week_start_day(week_day)
        for days_offset in range(7):
            current_day = week_start_date + timedelta(days=days_offset)
            log.info('getting week data day by the day', extra=d(week_start=week_day, current_day=current_day))
            yield from self.day_data(current_day, symbol)

    def get_result_set(self, symbol: Symbol, start: datetime, end: datetime) -> TableList:
        query_str = f"""
            from(bucket: "tsdata")
              |> range(start: {dt_to_rfc3339(start)}, stop: {dt_to_rfc3339(end)})
              |> filter(fn: (r) => r["instrument"] == "{symbol.value}")
              |> filter(fn: (r) => r["_measurement"] == "price")
              |> pivot(rowKey: ["_time"], columnKey: ["_field"], valueColumn: "_value")
        """
        log.debug('q: %s', query_str)
        return self._query_api.query(query_str)

    def get_data_stream(
            self, start: datetime, end: datetime, symbol: Symbol
    ) -> PriceStream:
        log.debug('getting chunk starting', extra=d(start))
        results = self.get_result_set(symbol, start, end)
        log.info('query-result', extra={'r': results})

        for _time, ask, bid in results.to_values(columns=('_time', 'ask', 'bid')):
            yield PricePoint(_time, ask, bid)


def get_data_reader() -> DataReader:
    return DataReader(
        config.influx_url,
        config.influx_token,
        config.influx_org
    )
